@@ -1,3 +1,4 @@
+use std::error;
 use std::fmt;
 use std::io;
 
@@ -49,9 +50,9 @@ impl SinkError for io::Error {
 
 /// A `Box<std::error::Error>` can be used as an error for `Sink`
 /// implementations out of the box.
-impl SinkError for Box<::std::error::Error> {
-    fn error_message<T: fmt::Display>(message: T) -> Box<::std::error::Error> {
-        Box::<::std::error::Error>::from(message.to_string())
+impl SinkError for Box<dyn error::Error> {
+    fn error_message<T: fmt::Display>(message: T) -> Box<dyn error::Error> {
+        Box::<dyn error::Error>::from(message.to_string())
     }
 }
 
@@ -167,6 +168,28 @@ pub trait Sink {
         Ok(true)
     }
 
+    /// This method is called whenever binary detection is enabled and binary
+    /// data is found. If binary data is found, then this is called at least
+    /// once for the first occurrence with the absolute byte offset at which
+    /// the binary data begins.
+    ///
+    /// If this returns `true`, then searching continues. If this returns
+    /// `false`, then searching is stopped immediately and `finish` is called.
+    ///
+    /// If this returns an error, then searching is stopped immediately,
+    /// `finish` is not called and the error is bubbled back up to the caller
+    /// of the searcher.
+    ///
+    /// By default, it does nothing and returns `true`.
+    #[inline]
+    fn binary_data(
+        &mut self,
+        _searcher: &Searcher,
+        _binary_byte_offset: u64,
+    ) -> Result<bool, Self::Error> {
+        Ok(true)
+    }
+
     /// This method is called when a search has begun, before any search is
     /// executed. By default, this does nothing.
     ///
@@ -177,10 +200,7 @@ pub trait Sink {
     /// `finish` is not called and the error is bubbled back up to the caller
     /// of the searcher.
     #[inline]
-    fn begin(
-        &mut self,
-        _searcher: &Searcher,
-    ) -> Result<bool, Self::Error> {
+    fn begin(&mut self, _searcher: &Searcher) -> Result<bool, Self::Error> {
         Ok(true)
     }
 
@@ -229,10 +249,16 @@ impl<'a, S: Sink> Sink for &'a mut S {
     }
 
     #[inline]
-    fn begin(
+    fn binary_data(
         &mut self,
         searcher: &Searcher,
+        binary_byte_offset: u64,
     ) -> Result<bool, S::Error> {
+        (**self).binary_data(searcher, binary_byte_offset)
+    }
+
+    #[inline]
+    fn begin(&mut self, searcher: &Searcher) -> Result<bool, S::Error> {
         (**self).begin(searcher)
     }
 
@@ -276,10 +302,16 @@ impl<S: Sink + ?Sized> Sink for Box<S> {
     }
 
     #[inline]
-    fn begin(
+    fn binary_data(
         &mut self,
         searcher: &Searcher,
+        binary_byte_offset: u64,
     ) -> Result<bool, S::Error> {
+        (**self).binary_data(searcher, binary_byte_offset)
+    }
+
+    #[inline]
+    fn begin(&mut self, searcher: &Searcher) -> Result<bool, S::Error> {
         (**self).begin(searcher)
     }
 
@@ -467,8 +499,8 @@ pub mod sinks {
     use std::io;
     use std::str;
 
-    use searcher::Searcher;
     use super::{Sink, SinkError, SinkMatch};
+    use searcher::Searcher;
 
     /// A sink that provides line numbers and matches as strings while ignoring
     /// everything else.
@@ -487,10 +519,12 @@ pub mod sinks {
     /// number of the first line in the match.
     #[derive(Clone, Debug)]
     pub struct UTF8<F>(pub F)
-        where F: FnMut(u64, &str) -> Result<bool, io::Error>;
+    where
+        F: FnMut(u64, &str) -> Result<bool, io::Error>;
 
     impl<F> Sink for UTF8<F>
-    where F: FnMut(u64, &str) -> Result<bool, io::Error>
+    where
+        F: FnMut(u64, &str) -> Result<bool, io::Error>,
     {
         type Error = io::Error;
 
@@ -533,10 +567,12 @@ pub mod sinks {
     /// number of the first line in the match.
     #[derive(Clone, Debug)]
     pub struct Lossy<F>(pub F)
-        where F: FnMut(u64, &str) -> Result<bool, io::Error>;
+    where
+        F: FnMut(u64, &str) -> Result<bool, io::Error>;
 
     impl<F> Sink for Lossy<F>
-    where F: FnMut(u64, &str) -> Result<bool, io::Error>
+    where
+        F: FnMut(u64, &str) -> Result<bool, io::Error>,
     {
         type Error = io::Error;
 
@@ -581,10 +617,12 @@ pub mod sinks {
     /// number of the first line in the match.
     #[derive(Clone, Debug)]
     pub struct Bytes<F>(pub F)
-        where F: FnMut(u64, &[u8]) -> Result<bool, io::Error>;
+    where
+        F: FnMut(u64, &[u8]) -> Result<bool, io::Error>;
 
     impl<F> Sink for Bytes<F>
-    where F: FnMut(u64, &[u8]) -> Result<bool, io::Error>
+    where
+        F: FnMut(u64, &[u8]) -> Result<bool, io::Error>,
     {
         type Error = io::Error;
 
